@@ -28,25 +28,18 @@ use Eccube\Application;
 use Eccube\Common\Constant;
 use Eccube\Controller\AbstractController;
 use Eccube\Exception\PluginException;
-use Eccube\Util\Cache;
 use Eccube\Util\Str;
+use Monolog\Logger;
 use Symfony\Component\Filesystem\Filesystem;
 use Symfony\Component\Finder\Finder;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
 use Symfony\Component\Routing\Exception\RouteNotFoundException;
 use Symfony\Component\Validator\Constraints as Assert;
-use Symfony\Component\Form\FormError;
-use Monolog\Logger;
 
 class PluginController extends AbstractController
 {
 
-    /**
-     * @var string 証明書ファイル
-     */
-    private $certFileName = 'cacert.pem';
-
     /**
      * インストール済プラグイン画面
      *
@@ -59,7 +52,7 @@ class PluginController extends AbstractController
         $pluginForms = array();
         $configPages = array();
 
-        $Plugins = $app['eccube.repository.plugin']->findBy(array(), array('name' => 'ASC'));
+        $Plugins = $app['eccube.repository.plugin']->findBy(array(), array('code' => 'ASC'));
 
         // ファイル設置プラグインの取得.
         $unregisterdPlugins = $this->getUnregisteredPlugins($Plugins, $app);
@@ -200,8 +193,6 @@ class PluginController extends AbstractController
 
                     $app->addSuccess('admin.plugin.update.complete', 'admin');
 
-                    Cache::clear($app, false);
-
                     return $app->redirect($app->url('admin_store_plugin'));
 
                 } catch (PluginException $e) {
@@ -578,9 +569,6 @@ class PluginController extends AbstractController
 
                                 $service->update($Plugin, $tmpDir.'/'.$tmpFile);
                                 $app->addSuccess('admin.plugin.update.complete', 'admin');
-
-                                Cache::clear($app, false);
-
                             }
 
                             $fs = new Filesystem();
@@ -666,58 +654,6 @@ class PluginController extends AbstractController
     }
 
 
-    /**
-     * 認証キーダウンロード
-     *
-     * @param Application $app
-     * @param Request $request
-     * @return \Symfony\Component\HttpFoundation\RedirectResponse
-     */
-    public function download(Application $app, Request $request)
-    {
-
-        $this->isTokenValid($app);
-
-        $url = $app['config']['cacert_pem_url'];
-
-        $curl = curl_init($url);
-        $fileName = $app['config']['root_dir'].'/app/config/eccube/'.$this->certFileName;
-        $fp = fopen($fileName, 'w');
-        if ($fp === false) {
-            $app->addError('admin.plugin.download.pem.error', 'admin');
-            $app->log('Cannot fopen to '.$fileName, array(), Logger::ERROR);
-            return $app->redirect($app->url('admin_store_authentication_setting'));
-        }
-
-        curl_setopt($curl, CURLOPT_FILE, $fp);
-        curl_setopt($curl, CURLOPT_HEADER, 0);
-
-        $results = curl_exec($curl);
-        $error = curl_error($curl);
-        curl_close($curl);
-
-        // curl で取得できない場合は file_get_contents で取得を試みる
-        if ($results === false) {
-            $file = file_get_contents($url);
-            if ($file !== false) {
-                fwrite($fp, $file);
-            }
-        }
-        fclose($fp);
-
-        $f = new Filesystem();
-        if ($f->exists($fileName) && filesize($fileName) > 0) {
-            $app->addSuccess('admin.plugin.download.pem.complete', 'admin');
-        } else {
-            $app->addError('admin.plugin.download.pem.error', 'admin');
-            $app->log('curl_error: '.$error, array(), Logger::ERROR);
-        }
-
-        return $app->redirect($app->url('admin_store_authentication_setting'));
-
-    }
-
-
     /**
      * APIリクエスト処理
      *
@@ -742,17 +678,10 @@ class PluginController extends AbstractController
             CURLOPT_SSL_VERIFYPEER => true,
             CURLOPT_RETURNTRANSFER => true,
             CURLOPT_FAILONERROR => true,
+            CURLOPT_CAINFO => \Composer\CaBundle\CaBundle::getSystemCaRootBundlePath(),
         );
 
         curl_setopt_array($curl, $options); /// オプション値を設定
-
-        $certFile = $app['config']['root_dir'].'/app/config/eccube/'.$this->certFileName;
-        if (file_exists($certFile)) {
-            // php5.6でサーバ上に適切な証明書がなければhttps通信エラーが発生するため、
-            // http://curl.haxx.se/ca/cacert.pem を利用して通信する
-            curl_setopt($curl, CURLOPT_CAINFO, $certFile);
-        }
-
         $result = curl_exec($curl);
         $info = curl_getinfo($curl);
 
