@@ -29,6 +29,7 @@ use Eccube\Common\Constant;
 use Eccube\Entity\Customer;
 use Eccube\Entity\Delivery;
 use Eccube\Entity\MailHistory;
+use Eccube\Entity\Master\DeviceType;
 use Eccube\Entity\Order;
 use Eccube\Entity\OrderDetail;
 use Eccube\Entity\Product;
@@ -112,6 +113,9 @@ class ShoppingService
         if (is_null($nonMember)) {
             return null;
         }
+        if (!array_key_exists('customer', $nonMember) || !array_key_exists('pref', $nonMember)) {
+            return null;
+        }
 
         $Customer = $nonMember['customer'];
         $Customer->setPref($this->app['eccube.repository.master.pref']->find($nonMember['pref']));
@@ -166,6 +170,14 @@ class ShoppingService
         $Order = $this->getNewOrder($Customer);
         $Order->setPreOrderId($preOrderId);
 
+        // device type
+        if ($this->app['mobile_detect']->isMobile()) {
+            $DeviceType = $this->app['eccube.repository.master.device_type']->find(DeviceType::DEVICE_TYPE_SP);
+        } else {
+            $DeviceType = $this->app['eccube.repository.master.device_type']->find(DeviceType::DEVICE_TYPE_PC);
+        }
+        $Order->setDeviceType($DeviceType);
+
         $this->em->persist($Order);
 
         // 配送業者情報を取得
@@ -221,6 +233,7 @@ class ShoppingService
 
     /**
      * 受注情報を作成
+     *
      * @param $Customer
      * @return \Eccube\Entity\Order
      */
@@ -235,12 +248,14 @@ class ShoppingService
 
     /**
      * 受注情報を作成
+     *
      * @return \Eccube\Entity\Order
      */
     public function newOrder()
     {
         $OrderStatus = $this->app['eccube.repository.order_status']->find($this->app['config']['order_processing']);
         $Order = new \Eccube\Entity\Order($OrderStatus);
+
         return $Order;
     }
 
@@ -543,7 +558,7 @@ class ShoppingService
 
         // 商品ごとの配送料合計
         $productDeliveryFeeTotal = 0;
-        if (!is_null($this->BaseInfo->getOptionProductDeliveryFee())) {
+        if ($this->BaseInfo->getOptionProductDeliveryFee() === Constant::ENABLED) {
             $productDeliveryFeeTotal = $ProductClass->getDeliveryFee() * $quantity;
         }
 
@@ -605,6 +620,7 @@ class ShoppingService
         foreach ($shipmentItems as $ShipmentItem) {
             $productDeliveryFeeTotal += $ShipmentItem->getProductClass()->getDeliveryFee() * $ShipmentItem->getQuantity();
         }
+
         return $productDeliveryFeeTotal;
     }
 
@@ -655,7 +671,7 @@ class ShoppingService
 
         // 商品ごとの配送料合計
         $productDeliveryFeeTotal = 0;
-        if (!is_null($this->BaseInfo->getOptionProductDeliveryFee())) {
+        if ($this->BaseInfo->getOptionProductDeliveryFee() === Constant::ENABLED) {
             $productDeliveryFeeTotal += $this->getProductDeliveryFee($Shipping);
         }
 
@@ -717,22 +733,44 @@ class ShoppingService
      */
     public function isOrderProduct($em, \Eccube\Entity\Order $Order)
     {
-        // 商品公開ステータスチェック
         $orderDetails = $Order->getOrderDetails();
 
         foreach ($orderDetails as $orderDetail) {
+
+            // 商品削除チェック
+            if ($orderDetail->getProductClass()->getDelFlg()) {
+                // @deprecated 3.1以降ではexceptionをthrowする
+                // throw new ShoppingException('cart.product.delete');
+                return false;
+            }
+
+            // 商品公開ステータスチェック
             if ($orderDetail->getProduct()->getStatus()->getId() != \Eccube\Entity\Master\Disp::DISPLAY_SHOW) {
                 // 商品が非公開ならエラー
+
+                // @deprecated 3.1以降ではexceptionをthrowする
+                // throw new ShoppingException('cart.product.not.status');
                 return false;
             }
 
             // 購入制限数チェック
             if (!is_null($orderDetail->getProductClass()->getSaleLimit())) {
                 if ($orderDetail->getQuantity() > $orderDetail->getProductClass()->getSaleLimit()) {
+                    // @deprecated 3.1以降ではexceptionをthrowする
+                    // throw new ShoppingException('cart.over.sale_limit');
                     return false;
                 }
             }
 
+            // 購入数チェック
+            if ($orderDetail->getQuantity() < 1) {
+                // 購入数量が1未満ならエラー
+
+                // @deprecated 3.1以降ではexceptionをthrowする
+                // throw new ShoppingException('???');
+                return false;
+            }
+
         }
 
         // 在庫チェック
@@ -745,7 +783,13 @@ class ShoppingService
                     $orderDetail->getProductClass()->getProductStock()->getId(), LockMode::PESSIMISTIC_WRITE
                 );
                 // 購入数量と在庫数をチェックして在庫がなければエラー
-                if ($orderDetail->getQuantity() > $productStock->getStock()) {
+                if ($productStock->getStock() < 1) {
+                    // @deprecated 3.1以降ではexceptionをthrowする
+                    // throw new ShoppingException('cart.over.stock');
+                    return false;
+                } elseif ($orderDetail->getQuantity() > $productStock->getStock()) {
+                    // @deprecated 3.1以降ではexceptionをthrowする
+                    // throw new ShoppingException('cart.over.stock');
                     return false;
                 }
             }
@@ -784,7 +828,7 @@ class ShoppingService
             $Shipping->setDeliveryFee($deliveryFee);
             // 商品ごとの配送料合計
             $productDeliveryFeeTotal = 0;
-            if (!is_null($this->BaseInfo->getOptionProductDeliveryFee())) {
+            if ($this->BaseInfo->getOptionProductDeliveryFee() === Constant::ENABLED) {
                 $productDeliveryFeeTotal += $this->getProductDeliveryFee($Shipping);
             }
             $Shipping->setShippingDeliveryFee($deliveryFee->getFee() + $productDeliveryFeeTotal);
@@ -956,25 +1000,27 @@ class ShoppingService
      */
     public function getFormPayments($deliveries, Order $Order)
     {
-
         $productTypes = $this->orderService->getProductTypes($Order);
 
         if ($this->BaseInfo->getOptionMultipleShipping() == Constant::ENABLED && count($productTypes) > 1) {
             // 複数配送時の支払方法
-
             $payments = $this->app['eccube.repository.payment']->findAllowedPayments($deliveries);
         } else {
-
             // 配送業者をセット
             $shippings = $Order->getShippings();
-            $Shipping = $shippings[0];
-            $payments = $this->app['eccube.repository.payment']->findPayments($Shipping->getDelivery(), true);
-
+            $payments = array();
+            foreach ($shippings as $Shipping) {
+                $paymentsShip = $this->app['eccube.repository.payment']->findPayments($Shipping->getDelivery(), true);
+                if (!$payments) {
+                    $payments = $paymentsShip;
+                } else {
+                    $payments = array_intersect($payments, $paymentsShip);
+                }
+            }
         }
         $payments = $this->getPayments($payments, $Order->getSubTotal());
 
         return $payments;
-
     }
 
     /**
