@@ -4,7 +4,9 @@ namespace Eccube\Tests\Service;
 
 use Eccube\Application;
 use Eccube\Common\Constant;
+use Eccube\Entity\Master\Taxrule;
 use Eccube\Entity\Shipping;
+use Eccube\Exception\ShoppingException;
 use Symfony\Component\Security\Core\Authentication\Token\UsernamePasswordToken;
 
 class ShoppingServiceTest extends AbstractServiceTestCase
@@ -275,11 +277,16 @@ class ShoppingServiceTest extends AbstractServiceTestCase
         }
         $this->app['orm.em']->flush();
 
-        $this->expected = false;
-        $this->actual = $this->app['eccube.service.shopping']->isOrderProduct(
-            $this->app['orm.em'],
-            $Order
-        );
+        try {
+            $this->app['eccube.service.shopping']->isOrderProduct(
+                $this->app['orm.em'],
+                $Order
+            );
+        } catch (ShoppingException $e) {
+            $this->actual = $e->getMessage();
+            $this->expected = 'cart.product.not.status';
+        }
+
         $this->verify();
     }
 
@@ -299,11 +306,16 @@ class ShoppingServiceTest extends AbstractServiceTestCase
         }
         $this->app['orm.em']->flush();
 
-        $this->expected = false;
-        $this->actual = $this->app['eccube.service.shopping']->isOrderProduct(
-            $this->app['orm.em'],
-            $Order
-        );
+        try {
+            $this->app['eccube.service.shopping']->isOrderProduct(
+                $this->app['orm.em'],
+                $Order
+            );
+        } catch (ShoppingException $e) {
+            $this->actual = $e->getMessage();
+            $this->expected = 'cart.over.sale_limit';
+        }
+
         $this->verify();
     }
 
@@ -327,11 +339,16 @@ class ShoppingServiceTest extends AbstractServiceTestCase
         }
         $this->app['orm.em']->flush();
 
-        $this->expected = false;
-        $this->actual = $this->app['eccube.service.shopping']->isOrderProduct(
-            $this->app['orm.em'],
-            $Order
-        );
+        try {
+            $this->app['eccube.service.shopping']->isOrderProduct(
+                $this->app['orm.em'],
+                $Order
+            );
+        } catch (ShoppingException $e) {
+            $this->actual = $e->getMessage();
+            $this->expected = 'cart.over.stock';
+        }
+
         $this->verify();
     }
 
@@ -532,4 +549,39 @@ class ShoppingServiceTest extends AbstractServiceTestCase
         $this->actual = count($Payments);
         $this->verify();
     }
+
+    /**
+     * #2005のテストケース
+     * @link https://github.com/EC-CUBE/ec-cube/issues/2005
+     */
+    public function testOrderDetailForTaxRate()
+    {
+
+        $Product = $this->app['eccube.repository.product']->find(1);
+        $ProductClasses = $Product->getProductClasses();
+
+        foreach ($ProductClasses as $ProductClass) {
+            $ProductClass->setPrice02(649);
+        }
+        $this->app['orm.em']->flush($Product);
+
+        $this->CartService->setProductQuantity($Product->getId(), 1)->save();
+
+        $Order = $this->app['eccube.service.shopping']->createOrder($this->Customer);
+        $TaxRule = $this->app['eccube.repository.tax_rule']->getByRule();
+
+        $TaxRule->setTaxRate(Taxrule::FLOOR);
+        $this->app['orm.em']->flush($TaxRule);
+
+        // 受注明細で設定された金額
+        foreach ($Order->getOrderDetails() as $OrderDetail) {
+
+            $this->expected = ($OrderDetail->getPrice() + $this->app['eccube.service.tax_rule']->calcTax($OrderDetail->getPrice(), $OrderDetail->getTaxRate(), $OrderDetail->getTaxRule())) * $OrderDetail->getQuantity();
+
+            $this->actual = ($OrderDetail->getPrice() + $this->app['eccube.service.tax_rule']->calcTax($OrderDetail->getPrice(), $OrderDetail->getTaxRate(), $TaxRule->getCalcRule()->getId())) * $OrderDetail->getQuantity();
+
+            $this->verify();
+        }
+
+    }
 }
